#!/usr/bin/python3

# We expect this to be executed module-style (as a tool, not a script)
# This script creates a default covid-19 config, using emod_api

import sys
import json
import emod_api.config.default_from_schema as default
from emodpy_covid.mid.schema_to_class import ReadOnlyDict

def app():
    default.write_default_from_schema()
    # default schema now stored as file on disk.
    # Let's load, replace some of the defaults with covid-19 settings and save.
    config = json.load( open( "default_config.json" ), object_hook=ReadOnlyDict )

    config.parameters.Simulation_Type="ENVIRONMENTAL_SIM"
    config.parameters.Enable_Termination_On_Zero_Total_Infectivity = 1
    config.parameters.Minimum_End_Time = 100
    config.parameters.Simulation_Duration = 365
    config.parameters.Enable_Vital_Dynamics = 0
    config.parameters.Enable_Event_DB = 1
    config.parameters.Demographics_Filenames = [ "covid_10k_demographics.json" ]
    config.parameters.Serialized_Population_Filenames = [ "hh_primary_10k.dtk" ]
    config.parameters.Base_Infectivity_Distribution = "EXPONENTIAL_DISTRIBUTION"
    config.parameters.Base_Infectivity_Exponential = 0.35
    config.parameters.Incubation_Period_Distribution = "GAUSSIAN_DISTRIBUTION"
    config.parameters.Incubation_Period_Gaussian_Mean = 8
    config.parameters.Incubation_Period_Gaussian_Std_Dev = 3
    config.parameters.Infectious_Period_Distribution = "GAMMA_DISTRIBUTION"
    config.parameters.Infectious_Period_Scale = 4
    config.parameters.Infectious_Period_Shape = 2
    config.parameters.Symptomatic_Infectious_Offset = 2
    config.parameters.Enable_Demographics_Reporting = 0
    config.parameters.Load_Balance_Filename = ""
    config = json.loads( json.dumps( config ) )
    config["parameters"]["Disable_IP_Whitelist"] = 1

    with open( "covid_config.json", "w" ) as config_file:
        json.dump( config, config_file, indent=4, sort_keys=True )

    # Now do stage1 config
    config = json.load( open( "default_config.json" ), object_hook=ReadOnlyDict )
    config.parameters.Simulation_Type="ENVIRONMENTAL_SIM"
    config.parameters.Demographics_Filenames = [ "demographics.json" ]
    config.parameters.Population_Scale_Type = "FIXED_SCALING"
    config.parameters.x_Base_Population = 10 # for 10k people
    config.parameters.Serialization_Type = "TIMESTEP"
    config.parameters.Serialization_Time_Steps = [ 0 ]
    config.parameters.Load_Balance_Filename = ""
    config.parameters.pop("Serialized_Population_Filenames")
    config = json.loads( json.dumps( config ) )
    config["parameters"]["Disable_IP_Whitelist"] = 1

    with open( "covid_config_stage1.json", "w" ) as config_file:
        json.dump( config, config_file, indent=4, sort_keys=True )

if __name__ == "__main__":
    if len( sys.argv ) == 0:
        print( "Usage: python3 -m emodpy-covid.config schema.json" )
    else:
        app()

