import json
import sqlite3
import os

def app( output_path ):
    """
    This post-processing function can be easily invoked from a dtk_post_process.py.
    The purpose is to populate otherwise empty New Infection By Route channels in 
    InsetChart.json from the event db. This is useful if you're using the transmission 
    tracing feature that disables the New Infection by Route reporting in InsetChart.json.
    """
    icj = json.loads( open( os.path.join( output_path, "InsetChart.json" ) ).read() )

    num_steps = icj["Header"]["Timesteps"]
    new_infs_contact = [0] * num_steps
    new_infs_enviro = [0] * num_steps
    with sqlite3.connect('simulation_events.db') as conn:
        cur = conn.cursor()
        query = "SELECT SIM_TIME, NOTES from SIM_EVENTS where EVENT=='NewInfection';"
        cur.execute( query )
        rows = cur.fetchall()
        for row in rows:
            time = row[0]
            props_and_route = row[1]
            if 'contact' in props_and_route.lower():
                new_infs_contact[ int(time) ] += 1
            elif 'environment' in props_and_route.lower():
                new_infs_enviro[ int(time) ] += 1

    # now populate channel in icj
    icj["Channels"]["New Infections By Route (CONTACT)"]["Data"] = new_infs_contact
    icj["Channels"]["New Infections By Route (ENVIRONMENT)"]["Data"] = new_infs_enviro
    with( open( os.path.join( output_path, "InsetChart.json" ), "w" ) ) as icj_save:
        json.dump( icj, icj_save )

